@@ -184,7 +184,7 @@ find_service_channel (bdaddr_t *adapter, bdaddr_t *device, gboolean only_gnapple
 {
 	sdp_session_t *sdp = NULL;
 	sdp_list_t *search = NULL, *attrs = NULL, *recs = NULL, *tmp;
-	uuid_t browse_uuid, service_id, obex_uuid;
+	uuid_t service_id;
 	uint32_t range = 0x0000ffff;
 	int channel = -1;
 
@@ -404,7 +404,7 @@ phonemgr_utils_driver_parse_start_tag (GMarkupParseContext *ctx,
 }
 
 static void
-totem_driver_model_free (void)
+phonemgr_driver_model_free (void)
 {
 	g_hash_table_destroy (driver_model);
 	driver_model = NULL;
@@ -420,7 +420,7 @@ phonemgr_utils_start_parse (void)
 	driver_model = g_hash_table_new_full
 		(g_str_hash, g_str_equal, g_free, g_free);
 
-	g_atexit (totem_driver_model_free);
+	g_atexit (phonemgr_driver_model_free);
 
 	if (g_file_get_contents (DATA_DIR"/phones.xml",
 				&buf, &buf_len, &err))
@@ -465,7 +465,6 @@ phonemgr_utils_guess_driver (PhonemgrState *phone_state, const char *device,
 {
 	const char *model;
 	char *driver;
-	gn_error err;
 
 	driver = phonemgr_utils_driver_for_device (device);
 	if (driver != NULL)
@@ -475,9 +474,7 @@ phonemgr_utils_guess_driver (PhonemgrState *phone_state, const char *device,
 		return NULL;
 
 	model = gn_lib_get_phone_model (&phone_state->state);
-
 	if (model == NULL) {
-		PhoneMgrError perr;
 		g_warning ("gn_lib_get_phone_model failed");
 		goto bail;
 	}
@@ -586,7 +583,7 @@ phonemgr_utils_tell_driver (const char *addr)
 	channel = -1;
 	type = phonemgr_utils_address_is (addr);
 	if (phonemgr_utils_connection_is_supported (type) == FALSE) {
-		g_warning ("Connection type isn't support by your gnokii build");
+		g_warning ("Connection type isn't supported by your libgnokii build");
 		return;
 	}
 
@@ -633,7 +630,7 @@ phonemgr_utils_write_gnokii_config (const char *addr)
 	channel = -1;
 	type = phonemgr_utils_address_is (addr);
 	if (phonemgr_utils_connection_is_supported (type) == FALSE) {
-		g_warning ("Connection type isn't support by your gnokii build");
+		g_warning ("Connection type isn't supported by your libgnokii build");
 		return;
 	}
 
